@@ -21,6 +21,7 @@ else:
 
 __all__ = (
     "ComponentFormatType",
+    "ComponentStatusType",
     "ComponentTypeType",
     "ContainerRepositoryServiceType",
     "ContainerTypeType",
@@ -36,6 +37,7 @@ __all__ = (
 
 
 ComponentFormatType = Literal["SHELL"]
+ComponentStatusType = Literal["DEPRECATED"]
 ComponentTypeType = Literal["BUILD", "TEST"]
 ContainerRepositoryServiceType = Literal["ECR"]
 ContainerTypeType = Literal["DOCKER"]
